﻿IF OBJECT_ID('[Executions_ImportLogEntries]') IS NOT NULL DROP PROCEDURE [Executions_ImportLogEntries]
GO

SET QUOTED_IDENTIFIER ON
GO

EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_ImportLogEntries',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Imports multiple log entries.'
GO

IF (SELECT compatibility_level FROM sys.databases WHERE name = DB_NAME()) < 100
EXEC sp_executesql N'
CREATE PROCEDURE [Executions_ImportLogEntries]
(
	@LogEntries_Table SQL_VARIANT
)
AS
BEGIN

SET NOCOUNT ON

RAISERROR(''This feature requires SQL Server 2008 or newer. If you are using SQL 2008 or newer and still getting this error, make sure the database compatibility level is at least 100.'',16,1)

END
'
ELSE BEGIN
EXEC sp_executesql N'
IF TYPE_ID(''ImportedScopedExecutionLogEntry'') IS NOT NULL DROP TYPE ImportedScopedExecutionLogEntry

CREATE TYPE ImportedScopedExecutionLogEntry AS TABLE
(
	[Execution_Id] INT NOT NULL,
	[LogEntry_Sequence] INT NOT NULL,
	[Scope_Sequence] INT NULL,
	[LogEntry_Level] INT NOT NULL,
	[LogEntry_Text] VARBINARY(MAX) NOT NULL,
	[LogEntry_Date] DATETIME NOT NULL
)
'

EXEC sp_executesql N'
GRANT EXECUTE ON TYPE::[ImportedScopedExecutionLogEntry] TO [BuildMasterUser_Role]
'

EXEC sp_executesql N'
CREATE PROCEDURE [Executions_ImportLogEntries]
(
	@LogEntries_Table dbo.ImportedScopedExecutionLogEntry READONLY
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [ScopedExecutionLogEntries]
	(
		[Execution_Id],
		[Scope_Sequence],
		[LogEntry_Sequence],
		[LogEntry_Level],
		[LogEntry_Text],
		[LogEntry_Date]
	)
	SELECT [Execution_Id],
	       [Scope_Sequence],
		   [LogEntry_Sequence],
		   [LogEntry_Level],
		   [LogEntry_Text],
		   [LogEntry_Date]
	  FROM @LogEntries_Table

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
'
END
GO

GRANT EXECUTE ON [Executions_ImportLogEntries] TO [BuildMasterUser_Role]
