EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_ChangeActionGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Moves an action into a different action group.'
GO


IF OBJECT_ID('[Plans_ChangeActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_ChangeActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_ChangeActionGroup]
(
	@DeploymentPlanActionGroup_Id INT,
	@Action_Sequence INT,
	@New_DeploymentPlanActionGroup_Id INT,
	@New_Action_Sequence INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	DECLARE @ActionGroup_Id INT
	DECLARE @DeploymentPlan_Id INT
	 SELECT @ActionGroup_Id = [ActionGroup_Id],
	        @DeploymentPlan_Id = [DeploymentPlan_Id]
	   FROM [DeploymentPlanActionGroups]
	  WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	DECLARE @New_ActionGroup_Id INT
	 SELECT @New_ActionGroup_Id = [ActionGroup_Id]
	   FROM [DeploymentPlanActionGroups]
	  WHERE [DeploymentPlanActionGroup_Id] = @New_DeploymentPlanActionGroup_Id

	BEGIN TRANSACTION

	IF (@ActionGroup_Id = @New_ActionGroup_Id)
	    RAISERROR('Actions cannot be moved to the same plan; use Plans_ResequenceAction instead.', 16, 1)

   DECLARE @Last_Action_Sequence INT
	SELECT @Last_Action_Sequence = COALESCE(MAX([Action_Sequence]), 1)
	  FROM [ActionGroupActions]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

   DECLARE @Target_Last_Action_Sequence INT
	SELECT @Target_Last_Action_Sequence = COALESCE(MAX([Action_Sequence]), 0) + 1
      FROM [ActionGroupActions]
     WHERE [ActionGroup_Id] = @New_ActionGroup_Id


	-- move action to end of list to appease trigger
	EXEC [Plans_ResequenceAction] @DeploymentPlanActionGroup_Id, @Action_Sequence, @Last_Action_Sequence

    -- move the action to the end of its new action group 
     UPDATE [ActionGroupActions]
        SET [ActionGroup_Id] = @New_ActionGroup_Id,
            [Action_Sequence] = @Target_Last_Action_Sequence
      WHERE [ActionGroup_Id] = @ActionGroup_Id
	    AND [Action_Sequence] = @Last_Action_Sequence

	-- move the action from the end of its action group to its new sequence
	EXEC [Plans_ResequenceAction] @New_DeploymentPlanActionGroup_Id, @Target_Last_Action_Sequence, @New_Action_Sequence

	-- disable reexecution for anything that used the containing plan of either group
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                                 INNER JOIN [DeploymentPlanActionGroups] DPAG
	                                         ON BEDP.[Original_DeploymentPlan_Id] = DPAG.[DeploymentPlan_Id]
	                           WHERE DPAG.[DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id
	                              OR DPAG.[DeploymentPlanActionGroup_Id] = @New_DeploymentPlanActionGroup_Id)

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_ChangeActionGroup] TO [BuildMasterUser_Role]