EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_DeleteDeploymentPlanActionGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes the specified action group.'
GO

IF OBJECT_ID('[Plans_DeleteDeploymentPlanActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_DeleteDeploymentPlanActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_DeleteDeploymentPlanActionGroup]
(
	@DeploymentPlanActionGroup_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ActionGroup_Id INT
	DECLARE @DeploymentPlanActionGroup_Sequence INT
	DECLARE @DeploymentPlan_Id INT

	 SELECT @DeploymentPlan_Id = [DeploymentPlan_Id],
	        @ActionGroup_Id = [ActionGroup_Id],
	        @DeploymentPlanActionGroup_Sequence = [DeploymentPlanActionGroup_Sequence]
	   FROM [DeploymentPlanActionGroups]
	  WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	DECLARE @Inst_Count INT
	SELECT @Inst_Count = COUNT(*)
	  FROM [DeploymentPlanActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

	-- move plan action group to the end of the sequence before deletion to appease triggers
	DECLARE @New_DeploymentPlanActionGroup_Sequence INT
	 SELECT @New_DeploymentPlanActionGroup_Sequence = MAX([DeploymentPlanActionGroup_Sequence])
	   FROM [DeploymentPlanActionGroups]
	  WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

	UPDATE [DeploymentPlanActionGroups]
	   SET [DeploymentPlanActionGroup_Sequence] = CASE
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] = CUR.[DeploymentPlanActionGroup_Sequence] 
	               THEN NEW.[DeploymentPlanActionGroup_Sequence]
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] BETWEEN CUR.[DeploymentPlanActionGroup_Sequence] AND NEW.[DeploymentPlanActionGroup_Sequence]
	               THEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] - 1
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] BETWEEN NEW.[DeploymentPlanActionGroup_Sequence] AND CUR.[DeploymentPlanActionGroup_Sequence]
	               THEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] + 1
	          ELSE [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence]
	          END
	  FROM [DeploymentPlanActionGroups],
	       [DeploymentPlanActionGroups] CUR,
	       [DeploymentPlanActionGroups] NEW
	 WHERE CUR.[DeploymentPlanActionGroup_Sequence] = @DeploymentPlanActionGroup_Sequence
	   AND NEW.[DeploymentPlanActionGroup_Sequence] = @New_DeploymentPlanActionGroup_Sequence
	   AND @DeploymentPlanActionGroup_Sequence <> @New_DeploymentPlanActionGroup_Sequence
	   AND [DeploymentPlanActionGroups].[DeploymentPlan_Id] = @DeploymentPlan_Id
	   AND CUR.[DeploymentPlan_Id] = @DeploymentPlan_Id
	   AND NEW.[DeploymentPlan_Id] = @DeploymentPlan_Id

	-- is this the last PlanActionGroup for the ActionGroup?
	IF @Inst_Count = 1
	BEGIN

		DELETE [ActionGroupActions]
		 WHERE [ActionGroup_Id] = @ActionGroup_Id

		-- delete the PlanActionGroup
		DELETE [DeploymentPlanActionGroups]
		 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

		-- delete the ActionGroup
		DELETE [ActionGroups]
		 WHERE [ActionGroup_Id] = @ActionGroup_Id

	END
	ELSE
	BEGIN

		-- if there is only one other instance left, unshare it
		IF @Inst_Count = 2
		BEGIN
			DECLARE @Other_DeploymentPlanActionGroup_Id INT
			SELECT @Other_DeploymentPlanActionGroup_Id = [DeploymentPlanActionGroup_Id]
			  FROM [DeploymentPlanActionGroups]
			 WHERE [DeploymentPlanActionGroup_Id] <> @DeploymentPlanActionGroup_Id
			   AND [ActionGroup_Id] = @ActionGroup_Id

			UPDATE [ActionGroups]
			   SET [ActionGroup_Name] = COALESCE(DPAG.[ActionGroup_Name], AG.[ActionGroup_Name]),
			       [Predicate_Configuration] = COALESCE(DPAG.[Predicate_Configuration], AG.[Predicate_Configuration]),
			       [ActionGroup_Description] = COALESCE(DPAG.[ActionGroup_Description], AG.[ActionGroup_Description]),
			       [Server_Id] = COALESCE(DPAG.[Server_Id], AG.[Server_Id]),
			       [Server_Variable_Name] = COALESCE(DPAG.[Server_Variable_Name], AG.[Server_Variable_Name])
			  FROM [ActionGroups] AG
			       INNER JOIN [DeploymentPlanActionGroups] DPAG
			               ON DPAG.[DeploymentPlanActionGroup_Id] = @Other_DeploymentPlanActionGroup_Id
			 WHERE AG.[ActionGroup_Id] = @ActionGroup_Id

			 UPDATE [DeploymentPlanActionGroups]
			    SET [ActionGroup_Name] = NULL,
			        [ActionGroup_Description] = NULL,
			        [Predicate_Configuration] = NULL,
                    [Server_Id] = NULL,
                    [Server_Variable_Name] = NULL
			  WHERE [DeploymentPlanActionGroup_Id] = @Other_DeploymentPlanActionGroup_Id
		END

		-- delete the PlanActionGroup
		DELETE [DeploymentPlanActionGroups]
		 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	END

 	-- disable reexecution for anything that used the modified plan
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                           WHERE BEDP.[Original_DeploymentPlan_Id] = @DeploymentPlan_Id)

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_DeleteDeploymentPlanActionGroup] TO [BuildMasterUser_Role]