EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RetentionPolicies_BeginPurge',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'RetentionPoliciesPurgeHistoryEntry_Id',
    /* Description_Text        */ 'Marks the start of a new purge.'
GO


IF OBJECT_ID('[RetentionPolicies_BeginPurge]') IS NOT NULL DROP PROCEDURE [RetentionPolicies_BeginPurge]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RetentionPolicies_BeginPurge]
(
	@RetentionPolicy_Id INT,
	@Original_RetentionPolicy_Name NVARCHAR(50),
	@RetentionPoliciesPurgeHistoryEntry_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	--Make sure this always gets reset
	UPDATE [RetentionPolicies]
	   SET [PurgeNow_Indicator] = 'N'
	 WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id

	DECLARE @History_Count INT
	SET @History_Count = (SELECT COUNT(*) FROM [RetentionPoliciesPurgeHistory] WITH (TABLOCKX))

	IF @History_Count > 1000
	BEGIN

		DECLARE @RowsToDelete TABLE ([RetentionPolicyPurgeHistoryEntry_Id] INT NOT NULL)

		INSERT INTO @RowsToDelete
		SELECT [RetentionPoliciesPurgeHistoryEntry_Id]
		  FROM (SELECT *,
		               [Rank] = ROW_NUMBER() OVER(ORDER BY [Start_Date] DESC)
				  FROM [RetentionPoliciesPurgeHistory]) _TMP
		 WHERE _TMP.[Rank] > 1000

		DELETE [RetentionPoliciesPurgeHistory]
		 WHERE [RetentionPoliciesPurgeHistoryEntry_Id] IN (SELECT [RetentionPolicyPurgeHistoryEntry_Id] FROM @RowsToDelete)

	END

	INSERT INTO [RetentionPoliciesPurgeHistory]
	(
		[Original_RetentionPolicy_Id],
		[Original_RetentionPolicy_Name],
		[Start_Date],
		[End_Date],
		[LogText_Bytes]
	)
	VALUES
	(
		@RetentionPolicy_Id,
		@Original_RetentionPolicy_Name,
		GETUTCDATE(),
		NULL,
		NULL
	)

	SET @RetentionPoliciesPurgeHistoryEntry_Id = SCOPE_IDENTITY()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RetentionPolicies_BeginPurge] TO [BuildMasterUser_Role]