EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateReleaseVariable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new release variable or sets an existing release variable''s value.'
GO

IF OBJECT_ID('[Variables_CreateOrUpdateReleaseVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateReleaseVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateReleaseVariable]
(
    @Release_Id INT,
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value VARBINARY(MAX),
    @Sensitive_Indicator YNINDICATOR,
    @EvaluateVariables_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [ReleaseVariables]
			   WHERE [Release_Id] = @Release_Id
                 AND [Variable_Name] = @Variable_Name)
	BEGIN

		UPDATE [ReleaseVariables]
		   SET [ValueType_Code] = @ValueType_Code,
		       [Variable_Value] = @Variable_Value,
               [Sensitive_Indicator] = @Sensitive_Indicator,
               [EvaluateVariables_Indicator] = @EvaluateVariables_Indicator
		 WHERE [Release_Id] = @Release_Id
           AND [Variable_Name] = @Variable_Name

	END
	ELSE
	BEGIN

		INSERT INTO [ReleaseVariables]
		(
			[Release_Id],
            [Variable_Name],
            [ValueType_Code],
			[Variable_Value],
            [Sensitive_Indicator],
            [EvaluateVariables_Indicator]
		)
		VALUES
		(
            @Release_Id,
            @Variable_Name,
            @ValueType_Code,
            @Variable_Value,
            @Sensitive_Indicator,
            @EvaluateVariables_Indicator
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateReleaseVariable] TO [BuildMasterUser_Role]
